@@ -203,19 +203,22 @@ class RKXMLRequest(XMLRequest):
         try:
             parsed_element = Etree.fromstring(response.content)
             for item in parsed_element.findall("./Visit"):
-                elements = item.iter()
-                for element in elements:
-                    order_dto = OrderListDTO(order_id=(element.attrib.get('OrderID')),
-                    order_name=(element.attrib.get('OrderName')), url=(element.attrib.get('Url')),
-                    version=(element.attrib.get('Version')), crc32=(element.attrib.get('Crc32')),
-                    guid=(element.attrib.get('Guid')), table_id=(element.attrib.get('TableId')),
-                    table_code=(element.attrib.get('TableCode')), order_categ_id=(element.attrib.get('OrderCategId')),
-                    order_categ_code=(element.attrib.get('OrderCategCode')), bill=(element.attrib.get('Bill')),
-                    waiter_id=(element.attrib.get('WaiterId')), order_type_code=(element.attrib.get('OrderTypeCode')),
-                    order_type_id=(element.attrib.get('OrderTypeId')), to_pay_sum=(element.attrib.get('ToPaySum')),
-                    waiter_code=(element.attrib.get('WaiterCode')), order_sum=(element.attrib.get('OrderSum')),
-                    total_pieces=(element.attrib.get('TotalPieces')), finished=(element.attrib.get('Finished')),
-                    price_list_sum=(element.attrib.get('PriceListSum')), dessert=(element.attrib.get('Dessert')))
+                visit = item.attrib
+                if item[0].tag == "Guests":
+                    order = item[1][0].attrib
+                    order_dto = OrderListDTO(visit_id=(visit.get('VisitID')),
+                    order_id=(order.get('OrderID')), count_guest=(visit.get('GuestsCount')),
+                    order_name=(order.get('OrderName')), url=(order.get('Url')),
+                    version=(order.get('Version')), crc32=(order.get('Crc32')),
+                    guid=(order.get('Guid')), table_id=(order.get('TableId')),
+                    table_code=(order.get('TableCode')), order_categ_id=(order.get('OrderCategId')),
+                    order_categ_code=(order.get('OrderCategCode')), bill=(order.get('Bill')),
+                    waiter_id=(order.get('WaiterId')), order_type_code=(order.get('OrderTypeCode')),
+                    order_type_id=(order.get('OrderTypeId')), to_pay_sum=(order.get('ToPaySum')),
+                    waiter_code=(order.get('WaiterCode')), order_sum=(order.get('OrderSum')),
+                    total_pieces=(order.get('TotalPieces')), finished=(order.get('Finished')),
+                    price_list_sum=(order.get('PriceListSum')), dessert=(order.get('Dessert')),
+                    created=(order.get('CreateTime')), finished_time=(order.get('FinishTime')))
                     element_list.append(order_dto)
         except (ParseError, ValueError) as error:
             raise ParseError(f"XML parse error - {str(error)}")
